@@ -1,7 +1,7 @@
 import argparse
 
+from pdm import termui
 from pdm.cli.commands.base import BaseCommand
-from pdm.iostream import stream
 from pdm.project import Project
 
 
@@ -32,39 +32,38 @@ class Command(BaseCommand):
             self._list_config(project, options)
 
     def _get_config(self, project: Project, options: argparse.Namespace) -> None:
-        stream.echo(project.config[options.key])
+        project.core.ui.echo(project.config[options.key])
 
     def _set_config(self, project: Project, options: argparse.Namespace) -> None:
         config = project.project_config if options.local else project.global_config
         config[options.key] = options.value
 
     def _list_config(self, project: Project, options: argparse.Namespace) -> None:
-        stream.echo(
-            "Home configuration ({}):".format(project.global_config._config_file)
-        )
-        with stream.indent("  "):
+        ui = project.core.ui
+        ui.echo("Home configuration ({}):".format(project.global_config._config_file))
+        with ui.indent("  "):
             for key in sorted(project.global_config):
-                stream.echo(
-                    stream.yellow(
+                ui.echo(
+                    termui.yellow(
                         "# " + project.global_config._config_map[key].description
                     ),
-                    verbosity=stream.DETAIL,
+                    verbosity=termui.DETAIL,
                 )
-                stream.echo(f"{stream.cyan(key)} = {project.global_config[key]}")
+                ui.echo(f"{termui.cyan(key)} = {project.global_config[key]}")
 
-        stream.echo()
-        stream.echo(
+        ui.echo()
+        ui.echo(
             "Project configuration ({}):".format(project.project_config._config_file)
         )
-        with stream.indent("  "):
+        with ui.indent("  "):
             for key in sorted(project.project_config):
-                stream.echo(
-                    stream.yellow(
+                ui.echo(
+                    termui.yellow(
                         "# " + project.project_config._config_map[key].description
                     ),
-                    verbosity=stream.DETAIL,
+                    verbosity=termui.DETAIL,
                 )
-                stream.echo(f"{stream.cyan(key)} = {project.project_config[key]}")
+                ui.echo(f"{termui.cyan(key)} = {project.project_config[key]}")
 
     def _delete_config(self, project: Project, options: argparse.Namespace) -> None:
         config = project.project_config if options.local else project.global_config
