@@ -3,9 +3,9 @@ import argparse
 from pdm.cli import actions
 from pdm.cli.commands.base import BaseCommand
 from pdm.cli.options import (
+    groups_group,
     install_group,
     save_strategy_group,
-    sections_group,
     update_strategy_group,
 )
 from pdm.project import Project
@@ -15,7 +15,7 @@ class Command(BaseCommand):
     """Update package(s) in pyproject.toml"""
 
     def add_arguments(self, parser: argparse.ArgumentParser) -> None:
-        sections_group.add_to_parser(parser)
+        groups_group.add_to_parser(parser)
         save_strategy_group.add_to_parser(parser)
         update_strategy_group.add_to_parser(parser)
         install_group.add_to_parser(parser)
@@ -39,6 +39,13 @@ class Command(BaseCommand):
             dest="dry_run",
             help="Show the difference only without modifying the lockfile content",
         )
+        parser.add_argument(
+            "--no-sync",
+            dest="sync",
+            default=True,
+            action="store_false",
+            help="Only update lock file but do not sync packages",
+        )
         parser.add_argument(
             "packages", nargs="*", help="If packages are given, only update them"
         )
@@ -48,7 +55,7 @@ class Command(BaseCommand):
         actions.do_update(
             project,
             dev=options.dev,
-            sections=options.sections,
+            groups=options.groups,
             default=options.default,
             save=options.save_strategy or project.config["strategy.save"],
             strategy=options.update_strategy or project.config["strategy.update"],
@@ -56,6 +63,7 @@ class Command(BaseCommand):
             top=options.top,
             dry_run=options.dry_run,
             packages=options.packages,
+            sync=options.sync,
             no_editable=options.no_editable,
             no_self=options.no_self,
         )
