@@ -51,7 +51,7 @@ def test_update_all_packages(project, repository, capsys):
     assert locked_candidates["chardet"].version == "3.0.5"
     assert locked_candidates["pytz"].version == "2019.6"
     out, _ = capsys.readouterr()
-    assert "3 to update" in out
+    assert "3 to update" in out, out
 
     actions.do_sync(project)
     out, _ = capsys.readouterr()
@@ -160,6 +160,18 @@ def test_remove_package(project, working_set, is_dev):
     assert "pytz" not in working_set
 
 
+@pytest.mark.usefixtures("repository")
+def test_remove_package_with_dry_run(project, working_set, capsys):
+    actions.do_add(project, packages=["requests"])
+    actions.do_remove(project, packages=["requests"], dry_run=True)
+    out, _ = capsys.readouterr()
+    project._lockfile = None
+    locked_candidates = project.locked_repository.all_candidates
+    assert "urllib3" in locked_candidates
+    assert "urllib3" in working_set
+    assert "- urllib3 1.22" in out
+
+
 @pytest.mark.usefixtures("repository")
 def test_remove_package_no_sync(project, working_set):
     actions.do_add(project, packages=["requests", "pytz"])
@@ -315,56 +327,49 @@ def test_list_json_without_graph_flag(project):
 
 @pytest.mark.usefixtures("repository", "working_set")
 def test_list_json(project, capsys):
-    actions.do_add(project, packages=["requests"])
+    actions.do_add(project, packages=["requests"], no_self=True)
     content, _ = capsys.readouterr()
     actions.do_list(project, graph=True, json=True)
     content, _ = capsys.readouterr()
     expected = [
         {
-            "package": "test-project",
-            "version": "0.0.0",
-            "required": "This project",
+            "package": "requests",
+            "version": "2.19.1",
+            "required": "~=2.19",
             "dependencies": [
                 {
-                    "package": "requests",
-                    "version": "2.19.1",
-                    "required": "~=2.19",
-                    "dependencies": [
-                        {
-                            "package": "certifi",
-                            "version": "2018.11.17",
-                            "required": ">=2017.4.17",
-                            "dependencies": [],
-                        },
-                        {
-                            "package": "chardet",
-                            "version": "3.0.4",
-                            "required": "<3.1.0,>=3.0.2",
-                            "dependencies": [],
-                        },
-                        {
-                            "package": "idna",
-                            "version": "2.7",
-                            "required": "<2.8,>=2.5",
-                            "dependencies": [],
-                        },
-                        {
-                            "package": "urllib3",
-                            "version": "1.22",
-                            "required": "<1.24,>=1.21.1",
-                            "dependencies": [],
-                        },
-                    ],
-                }
+                    "package": "certifi",
+                    "version": "2018.11.17",
+                    "required": ">=2017.4.17",
+                    "dependencies": [],
+                },
+                {
+                    "package": "chardet",
+                    "version": "3.0.4",
+                    "required": "<3.1.0,>=3.0.2",
+                    "dependencies": [],
+                },
+                {
+                    "package": "idna",
+                    "version": "2.7",
+                    "required": "<2.8,>=2.5",
+                    "dependencies": [],
+                },
+                {
+                    "package": "urllib3",
+                    "version": "1.22",
+                    "required": "<1.24,>=1.21.1",
+                    "dependencies": [],
+                },
             ],
-        },
+        }
     ]
     assert expected == loads(content)
 
 
 @pytest.mark.usefixtures("repository", "working_set")
 def test_list_json_reverse(project, capsys):
-    actions.do_add(project, packages=["requests"])
+    actions.do_add(project, packages=["requests"], no_self=True)
     capsys.readouterr()
     actions.do_list(project, graph=True, reverse=True, json=True)
     content, _ = capsys.readouterr()
@@ -378,14 +383,7 @@ def test_list_json_reverse(project, capsys):
                     "package": "requests",
                     "version": "2.19.1",
                     "requires": ">=2017.4.17",
-                    "dependents": [
-                        {
-                            "package": "test-project",
-                            "version": "0.0.0",
-                            "requires": "~=2.19",
-                            "dependents": [],
-                        }
-                    ],
+                    "dependents": [],
                 }
             ],
         },
@@ -398,14 +396,7 @@ def test_list_json_reverse(project, capsys):
                     "package": "requests",
                     "version": "2.19.1",
                     "requires": "<3.1.0,>=3.0.2",
-                    "dependents": [
-                        {
-                            "package": "test-project",
-                            "version": "0.0.0",
-                            "requires": "~=2.19",
-                            "dependents": [],
-                        }
-                    ],
+                    "dependents": [],
                 }
             ],
         },
@@ -418,14 +409,7 @@ def test_list_json_reverse(project, capsys):
                     "package": "requests",
                     "version": "2.19.1",
                     "requires": "<2.8,>=2.5",
-                    "dependents": [
-                        {
-                            "package": "test-project",
-                            "version": "0.0.0",
-                            "requires": "~=2.19",
-                            "dependents": [],
-                        }
-                    ],
+                    "dependents": [],
                 }
             ],
         },
@@ -438,14 +422,7 @@ def test_list_json_reverse(project, capsys):
                     "package": "requests",
                     "version": "2.19.1",
                     "requires": "<1.24,>=1.21.1",
-                    "dependents": [
-                        {
-                            "package": "test-project",
-                            "version": "0.0.0",
-                            "requires": "~=2.19",
-                            "dependents": [],
-                        }
-                    ],
+                    "dependents": [],
                 }
             ],
         },
@@ -458,22 +435,24 @@ def test_list_json_reverse(project, capsys):
 def test_list_json_with_circular_forward(project, capsys, repository):
     repository.add_candidate("foo", "0.1.0")
     repository.add_candidate("foo-bar", "0.1.0")
+    repository.add_candidate("baz", "0.1.0")
+    repository.add_dependencies("baz", "0.1.0", ["foo"])
     repository.add_dependencies("foo", "0.1.0", ["foo-bar"])
     repository.add_dependencies("foo-bar", "0.1.0", ["foo"])
-    actions.do_add(project, packages=["foo"])
+    actions.do_add(project, packages=["baz"], no_self=True)
     capsys.readouterr()
     actions.do_list(project, graph=True, json=True)
     content, _ = capsys.readouterr()
     expected = [
         {
-            "package": "test-project",
-            "version": "0.0.0",
-            "required": "This project",
+            "package": "baz",
+            "version": "0.1.0",
+            "required": "~=0.1",
             "dependencies": [
                 {
                     "package": "foo",
                     "version": "0.1.0",
-                    "required": "~=0.1",
+                    "required": "Any",
                     "dependencies": [
                         {
                             "package": "foo-bar",
@@ -504,7 +483,7 @@ def test_list_json_with_circular_reverse(project, capsys, repository):
     repository.add_dependencies("foo", "0.1.0", ["foo-bar"])
     repository.add_dependencies("foo-bar", "0.1.0", ["foo", "baz"])
     repository.add_dependencies("baz", "0.1.0", [])
-    actions.do_add(project, packages=["foo"])
+    actions.do_add(project, packages=["foo"], no_self=True)
     capsys.readouterr()
     actions.do_list(project, graph=True, json=True, reverse=True)
     content, _ = capsys.readouterr()
@@ -529,13 +508,7 @@ def test_list_json_with_circular_reverse(project, capsys, repository):
                                     "version": "0.1.0",
                                     "requires": "Any",
                                     "dependents": [],
-                                },
-                                {
-                                    "package": "test-project",
-                                    "version": "0.0.0",
-                                    "requires": "~=0.1",
-                                    "dependents": [],
-                                },
+                                }
                             ],
                         }
                     ],
