@@ -29,6 +29,31 @@ def test_pep582_launcher_for_python_interpreter(project, invoke):
     assert output.decode().strip() == "2.24.0"
 
 
+def test_auto_isolate_site_packages(project, invoke):
+    env = os.environ.copy()
+    env.update({"PYTHONPATH": PEP582_PATH})
+    proc = subprocess.run([project.python.executable, "-c", "import click"], env=env)
+    assert proc.returncode == 0
+
+    result = invoke(["run", "python", "-c", "import click"], obj=project)
+    if os.name != "nt":  # os.environ handling seems problematic on Windows
+        assert result.exit_code != 0
+
+
+def test_run_with_site_packages(project, invoke):
+    project.tool_settings["scripts"] = {
+        "foo": {"cmd": "python -c 'import click'", "site_packages": True}
+    }
+    project.write_pyproject()
+    result = invoke(
+        ["run", "--site-packages", "python", "-c", "import click"], obj=project
+    )
+    assert result.exit_code == 0
+
+    result = invoke(["run", "foo"], obj=project)
+    assert result.exit_code == 0
+
+
 def test_run_command_not_found(invoke):
     result = invoke(["run", "foobar"])
     assert "Command 'foobar' is not found on your PATH." in result.stderr
